@@ -7,16 +7,13 @@ deg2num <- function(x)
     sapply(x, deg2num)  # recursion supports element-specific format
   else
   {
-    ## 1 Determine sign (positive or negative)
+    ## 1  Determine sign (positive or negative)
     first.char <- substring(x, first=1, last=1)
-    if(first.char == "-")
-      sign <- -1
-    else if(is.digit(first.char))
-      sign <- 1
-    else
-      stop("First character must be \"-\" or number.")
+    sign <- if(first.char == "-") -1
+    else if(is.digit(first.char)) 1
+    else stop("first character must be \"-\" or number")
 
-    ## 2 Look at last character: cut it off if W|E|S|N and change sign if W|S
+    ## 2  Look at last character: cut it off if W|E|S|N and change sign if W|S
     last.char <- substring(x, first=nchar(x), last=nchar(x))
     if(last.char=="W" || last.char=="E" || last.char=="S" || last.char=="N")
     {
@@ -27,16 +24,17 @@ deg2num <- function(x)
     else if(is.digit(last.char))
       string <- as.character(x)
     else
-      stop("Last character must be W, E, S, N, or number")
+      stop("last character must be W, E, S, N, or number")
 
-    ## 3 Split string at colons, convert to decimals, and catch split errors
+    ## 3  Split string at colons, convert to decimals, and catch split errors
     splits <- as.numeric(unlist(strsplit(string, ":")))
     splits <- rep(c(splits,0,0), length.out=3)
     if(all(is.digit(splits)))
       value <- sign * (abs(splits[1]) + splits[2]/60 + splits[3]/3600)
     else
-      stop("Unable to interpret geographic coordinates. See Appendix B.1.1 in GMT manual for correct formats.")
+      stop("unable to interpret coordinates;\n",
+           "see 'GMT File Formats' in GMT manual")
 
-    return(value)
+    value
   }
 }
